documentationtools.ReSTParagraph
================================

.. abjad-lineage:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph

.. autoclass:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.depth
      ~abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.depthwise_inventory
      ~abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.graph_order
      ~abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.improper_parentage
      ~abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.name
      ~abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.parent
      ~abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.proper_parentage
      ~abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.rest_format
      ~abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.root
      ~abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.text
      ~abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.wrap
      ~abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__copy__
      ~abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__deepcopy__
      ~abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__eq__
      ~abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__getstate__
      ~abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__ne__
      ~abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__repr__
      ~abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__setstate__

Bases
-----

- :py:class:`datastructuretools.TreeNode <abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.depth
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.depthwise_inventory
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.graph_order
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.parent
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.rest_format
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.root
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.name
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.text
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.wrap
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__copy__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__deepcopy__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__getstate__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__repr__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTParagraph.ReSTParagraph.ReSTParagraph.__setstate__
   :noindex:
